#!/usr/bin/python3
# -*- coding: utf-8 -*-
#
# Copyright (C) 2018-2019  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.

"""Setup script for fred-idl."""
from distutils.command.build import build
from distutils.command.sdist import sdist
from glob import glob
import subprocess

from setuptools import Command, setup


class BuildIdl(Command):
    """Command to generate python modules from IDL files."""

    user_options = [
        ('build-lib=', 'd', 'directory to "build" (copy) to'),
    ]

    def initialize_options(self):
        self.build_lib = None
        self.output_path = '.'
        self.idl_files = ''
        self.modules = ''

    def finalize_options(self):
        self.set_undefined_options('build', ('build_lib', 'build_lib'))

    def run(self):
        args = ['omniidl', '-bpython', '-Wbmodules=' + self.modules, '-Wbstubs=' + self.modules + '._stubs'
                ] + glob(self.idl_files)

        # Running omniidl
        self.execute(subprocess.check_call, [args], 'running omniidl')


class CustomBuild(build):
    sub_commands = [('build_idl', None)] + build.sub_commands


class CustomSdist(sdist):
    sub_commands = [('build_idl', None)] + sdist.sub_commands


setup(
    author='Vlastimil Zíma',
    cmdclass={
        'sdist': CustomSdist,
        'build': CustomBuild,
        'build_idl': BuildIdl,
    },
)
